# <font size="7"><span style='color:#0066cc'> **Welcome to pydap**<font size="3">


`pydap` is a Python implementation of the **Data Access Protocol** (**DAP**), also known as [OPeNDAP](http://www.opendap.org/). You can use `pydap` as a client to access thousands of
scientific datasets in a transparent and efficient way through the internet, or you can set up `pydap` as a server to make your data available through the internet via an URL.

Check out the content pages bundled with this sample book to see more.

```{tableofcontents}
```
